@@ -6,6 +6,7 @@ Handlers to process table configurations for each of the Census' different geogr
 import time
 import logging
 import collections
+import numpy as np
 import pandas as pd
 from us import states
 from census import Census
@@ -21,6 +22,7 @@ class BaseGeoTypeDownloader(object):
     Expects a TableConfig instance and year as input.
     """
     YEAR_LIST = [
+        2020,
         2019,
         2018,
         2017,
@@ -171,7 +173,7 @@ class BaseGeoTypeDownloader(object):
         # Cast numbers to floats
         for field in field_name_mapper.keys():
             if "_" in field and (field.endswith("E") or field.endswith("M")):
-                df[field] = df[field].astype(pd.np.float64)
+                df[field] = df[field].astype(np.float64)
 
         # Rename fields with humanized names
         df.rename(columns=field_name_mapper, inplace=True)
@@ -359,6 +361,7 @@ class CnectasDownloader(BaseGeoTypeDownloader):
     Download raw data at the combined New England city and town level.
     """
     YEAR_LIST = [
+        2020,
         2019,
         2018,
         2017,
@@ -399,6 +402,7 @@ class ZctasDownloader(BaseGeoTypeDownloader):
     Download raw data at the zipcode-tabulation-area level.
     """
     YEAR_LIST = [
+        2020,
         2019,
         2018,
         2017,
